from setuptools import setup

setup(name='nsm',
      version='0.1',
      description='A NS-3 Simulation Manager',
      url='http://github.com/rgrunbla/nsm',
      author='Rémy Grünblatt',
      author_email='remy@grunblatt.org',
      license='MIT',
      packages=['nsm'],
      zip_safe=False)